pub struct IndexSchedulerDiagnostics {
pub next_refresh_at: Option<String>,
pub last_attempt_at: Option<String>,
pub last_success_at: Option<String>,
pub last_success_duration_ms: Option<u64>,
pub retry_after: Option<String>,
pub consecutive_failures: u32,
pub circuit_open: bool,
}Expand description
Scheduler and retry information for a persistent namespace index.
Fields
next_refresh_at: Option<String>last_attempt_at: Option<String>last_success_at: Option<String>last_success_duration_ms: Option<u64>retry_after: Option<String>consecutive_failures: u32circuit_open: boolTrait Implementations
Sourceimpl Clone for IndexSchedulerDiagnostics
impl Clone for IndexSchedulerDiagnostics
Sourcefn clone(&self) -> IndexSchedulerDiagnostics
fn clone(&self) -> IndexSchedulerDiagnostics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IndexSchedulerDiagnostics
impl Debug for IndexSchedulerDiagnostics
Sourceimpl Default for IndexSchedulerDiagnostics
impl Default for IndexSchedulerDiagnostics
Sourcefn default() -> IndexSchedulerDiagnostics
fn default() -> IndexSchedulerDiagnostics
Returns the “default value” for a type. Read more
impl Eq for IndexSchedulerDiagnostics
Sourceimpl PartialEq for IndexSchedulerDiagnostics
impl PartialEq for IndexSchedulerDiagnostics
Sourcefn eq(&self, other: &IndexSchedulerDiagnostics) -> bool
fn eq(&self, other: &IndexSchedulerDiagnostics) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for IndexSchedulerDiagnostics